@@ -336,8 +336,8 @@ class OvsHost(linux.LinuxDevice):
         '''
         Add some flows to ofproto
         '''
-        self.log("gw mac: %s" %(gw["mac"]))
-        self.log("mac: %s" %(self.macs))
+        #self.log("gw mac: %s" %(gw["mac"]))
+        #self.log("mac: %s" %(self.macs))
         if (gw["mac"] not in self.macs):
             # gw is not on this node, Add it as if it's on this node.
             ipaddr = ipaddress.ip_interface(gw["ip"]).ip
